@@ -26,24 +26,25 @@ import re
 
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
+    'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/pkg/bin',
     'default_mod_dir':    '/usr/pkg/lib/python2.7/site-packages',
     'default_sip_dir':    '/usr/pkg/share/sip2.7',
     'deployment_target':  '',
-    'platform':           'netbsd-g++',
+    'platform':           'linux-g++',
     'py_conf_inc_dir':    '/usr/pkg/include/python2.7',
     'py_inc_dir':         '/usr/pkg/include/python2.7',
     'py_lib_dir':         '/usr/pkg/lib/python2.7/config',
-    'py_version':         0x02070f,
+    'py_version':         0x020712,
     'qt_framework':       0,
     'sip_bin':            '/usr/pkg/bin/sip2.7',
-    'sip_config_args':    '-b /usr/pkg/bin -d /usr/pkg/lib/python2.7/site-packages -e /usr/pkg/include/python2.7 -v /usr/pkg/share/sip2.7 CFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include CXXFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include INCDIR=/usr/pkg/include LIBDIR=/usr/pkg/lib CFLAGS_SHLIB=-fPIC CXXFLAGS_SHLIB=-fPIC LFLAGS_SHLIB=-shared LFLAGS=   -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+    'sip_config_args':    '-b /usr/pkg/bin -d /usr/pkg/lib/python2.7/site-packages -e /usr/pkg/include/python2.7 -v /usr/pkg/share/sip2.7 CFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include CXXFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include INCDIR=/usr/pkg/include LIBDIR=/usr/pkg/lib CFLAGS_SHLIB=-fPIC CXXFLAGS_SHLIB=-fPIC LFLAGS_SHLIB=-shared LFLAGS= -Wl,-zrelro  -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
     'sip_inc_dir':        '/usr/pkg/include/python2.7',
     'sip_module_dir':     '/usr/pkg/lib/python2.7/site-packages',
     'sip_root_dir':       '/usr/pkg/lib/python2.7/site-packages',
-    'sip_version':        0x04130d,
-    'sip_version_str':    '4.19.13',
+    'sip_version':        0x041319,
+    'sip_version_str':    '4.19.25',
     'universal':          ''
 }
 
@@ -67,11 +68,11 @@ _default_macros = {
     'CFLAGS_SHLIB':             '-fPIC',
     'CFLAGS_STL_OFF':           '',
     'CFLAGS_STL_ON':            '',
-    'CFLAGS_THREAD':            '-pthread',
+    'CFLAGS_THREAD':            '-D_REENTRANT',
     'CFLAGS_WARN_OFF':          '-w',
     'CFLAGS_WARN_ON':           '-Wall -W',
     'CHK_DIR_EXISTS':           'test -d',
-    'CONFIG':                   'qt warn_on release link_prl',
+    'CONFIG':                   'qt warn_on release incremental link_prl',
     'COPY':                     'cp -f',
     'CXX':                      'g++',
     'CXXFLAGS':                 '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
@@ -90,7 +91,7 @@ _default_macros = {
     'CXXFLAGS_SHLIB':           '-fPIC',
     'CXXFLAGS_STL_OFF':         '',
     'CXXFLAGS_STL_ON':          '',
-    'CXXFLAGS_THREAD':          '-pthread',
+    'CXXFLAGS_THREAD':          '-D_REENTRANT',
     'CXXFLAGS_WARN_OFF':        '-w',
     'CXXFLAGS_WARN_ON':         '-Wall -W',
     'DEFINES':                  '',
@@ -100,7 +101,7 @@ _default_macros = {
     'INCDIR':                   '/usr/pkg/include',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '   -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+    'LFLAGS':                   ' -Wl,-zrelro  -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
@@ -111,7 +112,7 @@ _default_macros = {
     'LFLAGS_RPATH':             '',
     'LFLAGS_SHLIB':             '-shared',
     'LFLAGS_SONAME':            '-Wl,-soname,',
-    'LFLAGS_THREAD':            '-pthread',
+    'LFLAGS_THREAD':            '',
     'LFLAGS_WINDOWS':           '',
     'LFLAGS_WINDOWS_DLL':       '',
     'LIB':                      '',
@@ -126,18 +127,18 @@ _default_macros = {
     'LIBS_OPENGL':              '-lGLU -lGL',
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
-    'LIBS_THREAD':              '',
+    'LIBS_THREAD':              '-lpthread',
     'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
     'LINK':                     'g++',
     'LINK_SHLIB':               'g++',
-    'LINK_SHLIB_CMD':           'g++    -o    ',
+    'LINK_SHLIB_CMD':           '',
     'MAKEFILE_GENERATOR':       'UNIX',
     'MKDIR':                    'mkdir -p',
-    'RANLIB':                   'ranlib',
+    'RANLIB':                   '',
     'RPATH':                    '-Wl,-rpath,',
-    'STRIP':                    ''
+    'STRIP':                    'strip'
 }
 
 # The stack of configuration dictionaries.
